@@ -1,7 +1,7 @@
 package Data::Clean::Base;
 
 our $DATE = '2015-05-23'; # DATE
-our $VERSION = '0.25'; # VERSION
+our $VERSION = '0.26'; # VERSION
 
 use 5.010;
 use strict;
@@ -9,7 +9,7 @@ use warnings;
 use Log::Any::IfLOG '$log';
 
 use Function::Fallback::CoreOrPP qw(clone);
-use Scalar::Util qw(blessed);
+use Scalar::Util qw();
 
 sub new {
     my ($class, %opts) = @_;
@@ -165,7 +165,7 @@ sub _generate_cleanser_code {
     }
 
     # catch general object not caught by previous
-    for my $p ([-obj => 'blessed({{var}})']) {
+    for my $p ([-obj => 'Scalar::Util::blessed({{var}})']) {
         my $o = $opts->{$p->[0]};
         next unless $o;
         my $meth = "command_$o->[0]";
@@ -253,7 +253,7 @@ Data::Clean::Base - Base class for Data::Clean::*
 
 =head1 VERSION
 
-This document describes version 0.25 of Data::Clean::Base (from Perl distribution Data-Clean-JSON), released on 2015-05-23.
+This document describes version 0.26 of Data::Clean::Base (from Perl distribution Data-Clean-JSON), released on 2015-05-23.
 
 =for Pod::Coverage ^(command_.+)$
 
